@@ -2,13 +2,14 @@ package DBIx::SchemaChecksum;
 
 use 5.010;
 use Moose;
-use version; our $VERSION = version->new('0.20');
+use version; our $VERSION = version->new('0.21');
 
 use DBI;
 use Digest::SHA1;
 use Data::Dumper;
 use Path::Class;
 use Carp;
+use File::Find::Rule;
 
 with 'MooseX::Getopt';
 
@@ -295,7 +296,7 @@ sub apply_sql_snippets {
     my $self          = shift;
     my $this_checksum = shift;
     croak "No current checksum" unless $this_checksum;
-
+    
     my $update_path = $self->_update_path;
 
     my $update = $update_path->{$this_checksum}
@@ -304,8 +305,20 @@ sub apply_sql_snippets {
     unless ($update) {
         croak "No update found that's based on $this_checksum.\n";
     }
+    
+    if ($update->[0] eq 'SAME_CHECKSUM') {
+        return unless $update->[1];
+        my ($file, $expected_post_checksum)=splice(@$update,1,2);
+        
+        $self->apply_file($file, $expected_post_checksum);
+    }
+    else {
+        $self->apply_file(@$update);
+    }
+}
 
-    my ( $file, $expected_post_checksum ) = @$update;
+sub apply_file {
+    my ($self, $file, $expected_post_checksum ) = @_;
 
     my $yes = 0;
     if ( $self->no_prompt ) {
@@ -403,11 +416,31 @@ sub build_update_path {
     say "Checking directory $dir for checksum_files" if $self->verbose;
 
     my %update_info;
-    my @files = glob( $dir . "/*.sql" );
+    my @files = File::Find::Rule->file->name('*.sql')->in( $dir );
 
-    foreach my $file (@files) {
+    foreach my $file (sort @files) {
         my ( $pre, $post ) = $self->get_checksums_from_snippet($file);
-        $update_info{$pre} = [ Path::Class::File->new($file), $post ];
+        
+        if ($pre eq $post) {
+            if ($update_info{$pre}) {
+                unshift(@{$update_info{$pre}},'SAME_CHECKSUM');
+            }
+            else {
+                $update_info{$pre} = [ 'SAME_CHECKSUM' ];
+            }
+        }
+    
+        if ($update_info{$pre} && $update_info{$pre}->[0]  eq 'SAME_CHECKSUM') {
+            if ($post eq $pre) {
+                splice(@{$update_info{$pre}},1,0,Path::Class::File->new($file), $post);
+            }
+            else {
+                push(@{$update_info{$pre}},[ Path::Class::File->new($file), $post ]);
+            }
+        }
+        else {
+            $update_info{$pre} = [ Path::Class::File->new($file), $post ];
+        }
     }
 
     return $self->_update_path( \%update_info ) if %update_info;
